@@ -19,16 +19,16 @@ Copyright 2002 Peter Beerli and Joseph Felsenstein
 Copyright 2003-2008 Peter Beerli
 Copyright 2009 Peter Beerli and Michal Palczewski
  
-$Id: definitions.h 1542 2009-05-26 14:04:25Z beerli $
+$Id: definitions.h 1593 2009-12-06 22:42:27Z beerli $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.0.7"
+#define MIGRATEVERSION "3.1"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "3.0.7"
+#define MIGRATEVERSION "3.1"
 #endif
 #endif
 #ifndef MIGRATESUBVERSION
@@ -505,7 +505,7 @@ long chains is used */
 #define STOP                   1
 #define CONT                   3
 /* tree-print options */
-#define NONE                   0 /*+ */
+#define _NONE                   0 /*+ */
 #define ALL                    1 /*+ */
 #define BEST                   2 /*+ */
 #define LASTCHAIN              3 /*+ */
@@ -557,9 +557,15 @@ long chains is used */
 #define eventloop() /* eventloop would go here */
 #endif
 
+#define SUBLOCICHUNKS 10
+
 #ifdef powerpc
 #ifndef IBM
 #include <Accelerate/Accelerate.h>
 #endif
 #endif
+#undef MYINLINE 
+#define MYINLINE /*inline*/
+#undef PRETTY
+#define PRETTY
 #endif /*definitions */
