@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1564 2009-08-01 00:30:52Z beerli $*/
+/* $Id: main.c 1593 2009-12-06 22:42:27Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -65,6 +65,11 @@
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
+
+#ifdef SNOWLEOPARD
+#include <dispatch/dispatch.h>
+#endif
+
 //use this if you have nice() and need to be nice with others
 #ifdef HAVE_NICE
 #include <unistd.h>
@@ -506,8 +511,7 @@ main (int argc, char **argv)
 	if (options->uep)
 	  analyze_uep (EARTH);
 #endif
-        // profile tables
-        unset_penalizer_function (TRUE);	//now we calculate profile and shut down
+        // profile tables        unset_penalizer_function (TRUE);	//now we calculate profile and shut down
 	// the penalizing of far jumps in the maximizer function
       } // end of printing main tables and histograms
     
@@ -995,21 +999,20 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
     if (myID != MASTER)
     {
 #endif
-        if (options->heating)
-        {
-            for (i = 0; i < options->heated_chains; i++)
-            {
+      if (options->heating)
+	{
+	  for (i = 0; i < options->heated_chains; i++)
+	    {
 	      //free_tree(universe[i]->root, universe[i]);
-                free_timevector (universe[i]->treetimes);
-            }
-        }
-        else
-        {
+	      free_timevector (universe[i]->treetimes);
+	    }
+	}
+      else
+	{
 	  //free_tree(EARTH->root, EARTH);
-            free_timevector (EARTH->treetimes);
-        }
+	  free_timevector (EARTH->treetimes);
+	}
 #ifdef MPI
-        
     }
     myfree(twolongs);
 #endif
@@ -1025,9 +1028,12 @@ run_loci (world_fmt ** universe, int usize, option_fmt * options,
     //  long            i;
     for (locus = 0; locus < data->loci; locus++)
     {
-        run_locus (universe, usize, options, data,
-                   localheating_pool, maxreplicate, locus, treefilepos, Gmax);
-	free_datapart(data,options,locus);
+      if(!data->skiploci[locus])
+	{
+	  run_locus (universe, usize, options, data,
+		     localheating_pool, maxreplicate, locus, treefilepos, Gmax);
+	}
+      free_datapart(data,options,locus);
     }
 }
 
@@ -1115,7 +1121,7 @@ get_mighistdata (world_fmt * world, option_fmt * options)
 				    unpack_skyline_buffer);
 	      }
         }
-	if(world->options->treeprint ==BEST && world->options->treeinmemory==TRUE)
+	if(/*world->options->treeprint ==BEST &&*/ world->options->treeinmemory==TRUE)
 	  {
             mpi_results_master (MIGMPI_TREESPACE, world, maxreplicate,
                                 unpack_treespace_buffer);
@@ -1447,7 +1453,7 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
     long i;
 #endif
     
-    if (options->profile != NONE)
+    if (options->profile != _NONE)
     {
         world->buffer =
         (char *) myrealloc (world->buffer, SUPERLINESIZE * sizeof (char));
@@ -1565,7 +1571,7 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
   finish_mutationmodel(world, data, options);
   init_beagle(world,locus);
   set_beagle_instances(world,TRUE); // sets two instances for beagle
-  set_beagle_instances(world,FALSE); // so that wee can easily MCMC
+  //  set_beagle_instances(world,FALSE); // so that wee can easily MCMC
   fill_beagle_instances(world);
 #endif
   /*  if (world->replicate == 0)
@@ -1602,6 +1608,7 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
   world->allikemax = world->likelihood[0]; //-MYREAL_MAX;	/* for best tree option */
   world->treelen = 0.0;
   calc_treelength (world->root->next->back, &world->treelen);
+
 #ifdef UEP
   if (options->uep)
     {
@@ -1975,7 +1982,9 @@ run_updates (world_fmt ** universe,
              long inc, long increment, long step, long steps)
 {
 #ifndef  PTHREADS
+#ifndef SNOWLEOPARD
     long ii;
+#endif
 #endif
     if (options->heating)
     {
@@ -1983,10 +1992,31 @@ run_updates (world_fmt ** universe,
         fill_tpool (*localheating_pool, universe, usize);
         tpool_synchronize (*localheating_pool, usize);
 #else /*heating but not using threads */
+#ifdef SNOWLEOPARD
+        dispatch_queue_t queue = dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0);
+        dispatch_apply(options->heated_chains, queue,
+                       ^(unsigned long ii) {
+#ifdef FUNNYHEAT
+			 if(ii!=0)
+			   {
+			     reset_weight(universe[ii]);
+			   }
+#endif
+                         run_one_update (universe[ii]);
+                       }
+                       );
+#else
         for (ii = 0; ii < options->heated_chains; ii++)
         {
-            run_one_update (universe[ii]);
+#ifdef FUNNYHEAT
+	  if(ii!=0)
+	    {
+	      reset_weight(universe[ii]);
+	    }
+#endif
+	  run_one_update (universe[ii]);
         }
+#endif /*SNOWLEOPARD*/
 #endif /* end of not-using threads */
 	if(options->bayes_infer && RANDUM() > options->updateratio)
 	  {
@@ -2373,9 +2403,10 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   static boolean done=FALSE;
 #endif
   long t;
-  long hc = EARTH->options->heated_chains;
+  const long np = EARTH->numpop2;
+  const long hc = EARTH->options->heated_chains;
   long locus;
-  long maxreplicate = (options->replicate
+  const long maxreplicate = (options->replicate
 		       && options->replicatenum >
 		       0) ? options->replicatenum : 1;
   //  long lsteps = options->lsteps;
@@ -2427,14 +2458,14 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 #ifdef MPI
 	  // the thermodynamic integration is reporting maxreplicate times too high values
 	  // warning("this should fix the thermodynamic/mpi/replicate  problem, but needs to be checked for multilocus data");
-	  if(!done)
-	    {
+	  //	  if(!done)
+	  //  {
 	      for(t=0; t < hc; t++)
 		{
 		  EARTH->bf[locus * hc + t] /= maxreplicate;
 		}
-	      done=TRUE;
-	    }
+	      //      done=TRUE;
+	      //  }
 #endif
 	  // from very hot to cold, the 
 	  for(t=1; t < hc; t++)
@@ -2508,6 +2539,26 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	}
       if(EARTH->loci>1)
 	{
+#ifndef OLDBF
+	  long pop;
+	  long i;
+	  MYREAL scaling_factor=0.0;
+	  for(i=0;i<np;i++)
+	    {
+	      if(EARTH->bayes->map[i][1] == INVALID)
+		continue;
+	      else
+		{
+		  pop  = EARTH->bayes->map[i][1];
+		}
+	      scaling_factor += exp(EARTH->bayes->scaling_factors[pop] - EARTH->bayes->maxmaxvala);
+	      printf("%f\n",scaling_factor);
+	    }
+	  scaling_factor = log(scaling_factor) + EARTH->bayes->maxmaxvala;
+	  printf("%f\n",scaling_factor);
+	  bfsum += scaling_factor;
+	  bfsum2 += scaling_factor;
+#endif
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
 	  fprintf(file,"  All  %22.2f        %22.2f           %12.2f\n", bfsum, bfsum2, hsum); 
 #ifdef PRETTY
