@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1565 2009-08-03 14:48:56Z beerli $
+$Id: mcmc1.c 1589 2009-11-19 22:14:25Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -37,6 +37,10 @@ Tree changer and acceptance rejection scheme
 
 #include "bayes.h"
 
+#ifdef BEAGLE
+#include "calculator.h"
+#endif
+
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
@@ -126,10 +130,13 @@ set_tree_dirty (node * p)
 /*=======================================================*/
 long
 tree_update (world_fmt * world, long g)
-{    /*return 1 if tree was acceped 0 otherwise */
+{    /*return 1 if tree was accepted, 0 otherwise */
     static long treefilepos; /* write position in the treefile */
 #ifdef TESTING2
     static boolean have_proposal=FALSE;
+#endif
+#ifdef BEAGLE
+    int beagle_control=1;
 #endif
     //short show=0;
     boolean coalesced;
@@ -321,6 +328,7 @@ tree_update (world_fmt * world, long g)
       {
 #ifdef BEAGLE
 	printf("Accepted\n");
+	change_beagle(world->root->next->back,world->beagle,world->sumtips);
 #endif
 	if (proposal->time > world->root->tyme)
 	  {   /*saveguard */
@@ -354,17 +362,26 @@ tree_update (world_fmt * world, long g)
 	  }
 #else
 #ifdef BEAGLE
-	set_beagle_dirty(proposal->origin,proposal->target,showtop(world->root->next->back));
-	reset_beagle(world->beagle);
-	smooth (world->root->next, crawlback(world->root->next), world, world->locus);
-        world->likelihood[g] = treelikelihood (world);
+	//	set_beagle_dirty(proposal->origin,proposal->target,showtop(world->root->next->back));
+	//reset_beagle(world->beagle);
+	//smooth (world->root->next, crawlback(world->root->next), world, world->locus);
+	//if(world->beagle->numbranches>0)
+	//  {
+	world->likelihood[g] = proposal->likelihood; //treelikelihood (world);
+	if(beagle_control==1)
+	  {
+	    printf("Recalculate LnL using treelikelihood()\n");
+	    world->likelihood[g] = force_beagle_recalculate(world,world->locus);
+	    printf("%i> %f = newLnL=%f + recalcLnL=%f\n",myID, proposal->likelihood - world->likelihood[g], proposal->likelihood,world->likelihood[g]);
+	  }
+	//  }
 #else
         world->likelihood[g] = treelikelihood (world);
 #endif /*BEAGLE*/
 #endif /*UEP*/
         /* create a new timelist */
         construct_tymelist (world, &world->treetimes[0]);
-        if (world->options->treeprint != NONE && world->cold)
+        if (world->options->treeprint != _NONE && world->cold)
 	  print_tree (world, g, &treefilepos);
         world->migration_counts = 0;
         /* report the number of migration on the tree */
@@ -1159,7 +1176,7 @@ migration_from (long to, proposal_fmt * proposal)
     {
         ii++;
     }
-#ifdef DEBUG
+#ifdef TREEDEBUG
     if(r[ii] == 0.0)
       {
 	warning("DEBUG: migproblist does not contain a migration probability\n");
@@ -1632,10 +1649,9 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
       //            oldg = g;
       //        }
 #ifdef BEAGLE
-      change_beagle(world->beagle);
-      printf("Reset to: ");
-      set_beagle_dirty(proposal->origin,proposal->target,showtop(world->root->next->back));
-      calcLnL(world, world->beagle->instance);
+      printf("Reset to: %f\n",world->likelihood[g]);
+      //set_beagle_dirty(proposal->origin,proposal->target,showtop(world->root->next->back));
+      //calcLnL(world, world->beagle->instance);
 #endif
       return FALSE;
     }
@@ -1659,13 +1675,23 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
     proposal->likelihood = pseudotreelikelihood (world, proposal);
     //printf("DEBUG: proposal->likellihood=%f heat=%f\n",proposal->likelihood, world->heat);
 #endif
+
+    //if(proposal->likelihood <= -HUGE &&  world->likelihood[g] <= -HUGE)
+    //  {
+	//	if(!world->in_burnin)
+	//  {
+	    //long burnin = world->options->burn_in;
+	    //world->options->burn_in *= 10;
+	    //fprintf(stdout,"likelihood is -inf, insert a burn-in phase\n");
+	    //	    burnin_chain(world);
+	    //world->options->burn_in = burnin;
+	    //  }
+    //	return TRUE;
+    // }
+
     if (world->likelihood[g] < proposal->likelihood)
     {
       not_accepted = 0;
-#ifdef BEAGLE
-      //    printf("Adjust other instance: ");
-      //calcLnL(world,!world->beagle->instance);
-#endif
       return TRUE;
     }
     if (!world->options->heating)
@@ -1675,10 +1701,6 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
         if (rr < expo)
 	  {
 	    not_accepted = 0;
-#ifdef BEAGLE
-	    //    printf("Adjust other instance: ");
-	    //calcLnL(world,!world->beagle->instance);
-#endif
             return TRUE;
 	  }
     }
@@ -1689,26 +1711,13 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
         if (rr < expo)
 	  {
 	    not_accepted = 0;
-#ifdef BEAGLE
-	    //    printf("Adjust other instance: ");
-	    // calcLnL(world,!world->beagle->instance);
-#endif
             return TRUE;
 	  }
     }
     if(world->options->prioralone)
       {
-#ifdef BEAGLE
-	//    printf("Adjust other instance: ");
-	//calcLnL(world,!world->beagle->instance);
-#endif
 	return TRUE;
       }
-#ifdef BEAGLE
-    change_beagle(world->beagle);
-    printf("Reset to: ");
-    calcLnL(world,world->beagle->instance);
-#endif
     return FALSE;
 }
 
