@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1559 2009-06-22 23:57:06Z beerli $
+ $Id: sequence.c 1593 2009-12-06 22:42:27Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -94,17 +94,17 @@ void
 init_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
                 long locus)
 {
-    static boolean done = FALSE;
+
     long sites = world->data->seq[0]->sites[locus];
     if (world->options->datatype == 'u')
         sites *= 5;
-    if (!done)
+    if (!world->data->seq[0]->done || world->data->seq[0]->alias == NULL)
     {
-        done = TRUE;
+        world->data->seq[0]->done = TRUE;
         world->data->seq[0]->alias = (long *) mycalloc (1, sizeof (long) * sites);
         world->data->seq[0]->ally = (long *) mycalloc (1, sizeof (long) * sites);
-        world->data->seq[0]->aliasweight =
-            (long *) mycalloc (1, sizeof (long) * sites);
+        world->data->seq[0]->savealiasweight = (long *) mycalloc (sites, sizeof (long));
+        world->data->seq[0]->aliasweight = (long *) mycalloc (1, sizeof (long) * sites);
         world->data->seq[0]->location = (long *) mycalloc (1, sizeof (long) * sites);
         world->data->seq[0]->category = (long *) mycalloc (1, sizeof (long) * sites);
         world->data->seq[0]->weight = (short *) mycalloc (1, sizeof (short) * sites);
@@ -115,6 +115,9 @@ init_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
             (long *) myrealloc (world->data->seq[0]->alias, sizeof (long) * sites);
         world->data->seq[0]->ally =
             (long *) myrealloc (world->data->seq[0]->ally, sizeof (long) * sites);
+        world->data->seq[0]->savealiasweight =
+            (long *) myrealloc (world->data->seq[0]->savealiasweight,
+                              sizeof (long) * sites);
         world->data->seq[0]->aliasweight =
             (long *) myrealloc (world->data->seq[0]->aliasweight,
                               sizeof (long) * sites);
@@ -467,29 +470,31 @@ makeweights (world_fmt * world, data_fmt * data, option_fmt *options, long locus
 {
     /* make up weights vector to avoid duplicate computations */
     long i;
+    seqmodel_fmt *seq = world->data->seq[0];
     world->data->seq[0]->endsite = 1;
-    for (i = 0; i < world->data->seq[0]->sites[locus]; i++)
+    for (i = 0; i < seq->sites[locus]; i++)
     {
-        world->data->seq[0]->alias[i] = i + 1;
-        world->data->seq[0]->ally[i] = 0;
-        world->data->seq[0]->aliasweight[i] = world->data->seq[0]->weight[i];
-        world->data->seq[0]->location[i] = 0;
+        seq->alias[i] = i + 1;
+        seq->ally[i] = 0;
+        seq->aliasweight[i] = seq->weight[i];
+        seq->location[i] = 0;
     }
-    sitesort2 (world, data, options, world->data->seq[0]->sites[locus], locus);
-    sitecombine2 (world, data, options, world->data->seq[0]->sites[locus], locus);
-    sitescrunch2 (world, world->data->seq[0]->sites[locus], 1, 2, locus);
-    for (i = 1; i <= world->data->seq[0]->sites[locus]; i++)
+    sitesort2 (world, data, options, seq->sites[locus], locus);
+    sitecombine2 (world, data, options, seq->sites[locus], locus);
+    sitescrunch2 (world, seq->sites[locus], 1, 2, locus);
+    for (i = 1; i <= seq->sites[locus]; i++)
     {
-        if (world->data->seq[0]->aliasweight[i - 1] > 0)
-            world->data->seq[0]->endsite = i;
+        if (seq->aliasweight[i - 1] > 0)
+            seq->endsite = i;
     }
-    for (i = 1; i <= world->data->seq[0]->endsite; i++)
+    for (i = 1; i <= seq->endsite; i++)
     {
-        world->data->seq[0]->location[world->data->seq[0]->alias[i - 1] - 1] = i;
-        world->data->seq[0]->ally[world->data->seq[0]->alias[i - 1] - 1] =
-            world->data->seq[0]->alias[i - 1];
+        seq->location[seq->alias[i - 1] - 1] = i;
+        seq->ally[seq->alias[i - 1] - 1] =
+            seq->alias[i - 1];
     }
-    init_sequences2 (world, world->data->seq[0], locus);
+    init_sequences2 (world, seq, locus);
+    memcpy(seq->savealiasweight, seq->aliasweight, sizeof(long) * seq->endsite);
 }    /* makeweights */
 
 void
@@ -639,6 +644,7 @@ void
 makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
                 long locus)
 {
+  seqmodel_fmt *seq = world->data->seq[0];
   long ii, ind, j, k, l, pop, top;
   long z=0;
   node **treenode = world->nodep;
@@ -650,14 +656,7 @@ makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
   for (pop = 0; pop < data->numpop; pop++)
     {
       zpop = 0;
-      if(options->randomsubset>0 && options->randomsubset <  data->numind[pop][locus])
-	{	
-	  top = options->randomsubset;
-	}
-      else
-	{
-	  top = data->numind[pop][locus];
-	}
+      top = max_shuffled_individuals(options, data, pop, locus);
       for (ii = 0; ii < top; ii++)
 	{
 	  ind = data->shuffled[pop][locus][ii];
@@ -670,9 +669,9 @@ makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
 	      world->data->sampledates[pop][locus][ind].id = treenode[z]->id;
 	      z++;
 	    }	    
-	  for (k = 0; k < world->data->seq[0]->endsite; k++)
+	  for (k = 0; k < seq->endsite; k++)
 	    {
-	      j = world->data->seq[0]->alias[k] - 1;
+	      j = seq->alias[k] - 1;
 	      for (l = 0; l < world->options->rcategs; l++)
 		{                    
 		  set_nucleotide(treenode[z-1]->x.s[k][l],data->yy[pop][ind][locus][0][j], seqerr);
@@ -693,12 +692,13 @@ makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data,
   long i, ii, j, k, l, pop;
   long b, f;
   long ind;
+  seqmodel_fmt *seq = world->data->seq[0];
   node **treenode = world->nodep;
-  f = world->data->seq[0]->addon;
-  for (k = 0; k < world->data->seq[0]->endsite * (f + 1);
-       k += (1 + world->data->seq[0]->addon))
+  f = seq->addon;
+  for (k = 0; k < seq->endsite * (f + 1);
+       k += (1 + seq->addon))
     {
-      j = world->data->seq[0]->alias[k / (f + 1)] - 1;
+      j = seq->alias[k / (f + 1)] - 1;
       i = -1;
       for (pop = 0; pop < data->numpop; pop++)
 	{
