@@ -34,7 +34,7 @@ While[z2 [[2]] >  y, z2[[2]] = f[z[[2]] += stick]];
     x = Random[Real, z];
 While[(f[x]) < y && count++ < 100,
       If[(x - z[[1]]) < z[[2]] - x, z[[1]] = x, z[[2]] = x];
-      (*Print[{x, f[x]}];*)
+      Print[{x, f[x]}];
       x = Random[Real, z];
       ];
       {x, y}]
@@ -306,8 +306,6 @@ MYREAL expslice (MYREAL *startval, long which, world_fmt * world, MYREAL  (*func
   zl = x - r;
   zr = zl + stick;
   // extend the stick until it crosses the function
-  //  ezl = EXP(zl);
-  //ezr = EXP(zr);
   priorratio = func(zl, -1. , bayes, w);
   set_slice_param(zl,which, world);
   fzl= probg_treetimes(world) + priorratio;
@@ -361,7 +359,6 @@ MYREAL expslice (MYREAL *startval, long which, world_fmt * world, MYREAL  (*func
     {
       stick *= stick_reduce;
       count++;
-      //      if((x - zl) < (zr - x))
       if(x < newstartval)
 	{
 	  zl = x;
@@ -382,7 +379,7 @@ MYREAL expslice (MYREAL *startval, long which, world_fmt * world, MYREAL  (*func
       set_slice_param(x,which, world);
       fx = probg_treetimes(world) + priorratio;
 #ifdef SLICEREPORTER
-  fprintf(stdout,"#@ %f %f %s %li\n", x, fx,"new_x", count);
+      fprintf(stdout,"#@ %f %f %s %li\n", x, fx,"new_x", count);
 #endif
     }
   //fprintf(stdout,"{{%f,%f},{%f,%f},{%f,%f}} (* y=%f, c=%li, %li, lv=%f *)\n",zl,fzl,x,fx,zr,fzr,y, count, which,startval);
